@@ -272,7 +272,7 @@ func GenMarkdownCustom(cmd *cobra.Command, w io.Writer) error {
 	buf.WriteString("title: " + name + "\n")
 	buf.WriteString("stage: Create" + "\n")
 	buf.WriteString("group: Code Review" + "\n")
-	buf.WriteString("info: To determine the technical writer assigned to the Stage/Group associated with this page, see https://about.gitlab.com/handbook/product/ux/technical-writing/#assignments" + "\n")
+	buf.WriteString("info: To determine the technical writer assigned to the Stage/Group associated with this page, see <https://handbook.gitlab.com/handbook/product/ux/technical-writing/#assignments>" + "\n")
 	buf.WriteString("---" + "\n\n")
 
 	// Generated by a script
@@ -347,7 +347,7 @@ func GenRootMarkdownCustom(cmd *cobra.Command, w io.Writer) error {
 	buf.WriteString("title: GitLab CLI (glab)\n")
 	buf.WriteString("stage: Create" + "\n")
 	buf.WriteString("group: Code Review" + "\n")
-	buf.WriteString("info: To determine the technical writer assigned to the Stage/Group associated with this page, see https://about.gitlab.com/handbook/product/ux/technical-writing/#assignments" + "\n")
+	buf.WriteString("info: To determine the technical writer assigned to the Stage/Group associated with this page, see <https://handbook.gitlab.com/handbook/product/ux/technical-writing/#assignments>" + "\n")
 	buf.WriteString("---" + "\n\n")
 
 	// Generated by a script comment
@@ -367,7 +367,7 @@ func GenRootMarkdownCustom(cmd *cobra.Command, w io.Writer) error {
 	buf.WriteString("- View, manage, and retry CI/CD pipelines directly from your CLI.\n")
 	buf.WriteString("- Create changelogs.\n")
 	buf.WriteString("- Create and manage releases.\n")
-	buf.WriteString("- Ask GitLab Duo Chat questions about Git.\n")
+	buf.WriteString("- Ask GitLab Duo Chat (Classic) questions about Git.\n")
 	buf.WriteString("- Manage GitLab agents for Kubernetes.\n\n")
 	buf.WriteString("`glab` is available for repositories hosted on GitLab.com, GitLab Dedicated, and GitLab Self-Managed. It supports multiple authenticated GitLab instances, and automatically detects the authenticated hostname from the remotes available in your working Git directory.\n\n")
 	buf.WriteString("![command example](img/glabgettingstarted.gif)\n\n")
