@@ -90,7 +90,7 @@ func NewCmdCreate(f cmdutils.Factory) *cobra.Command {
 
 		`),
 		Annotations: map[string]string{
-			mcpannotations.Destructive: "true",
+			mcpannotations.Exclude: "true",
 		},
 		RunE: func(cmd *cobra.Command, args []string) error {
 			if err := opts.complete(cmd, args); err != nil {
@@ -108,7 +108,7 @@ func NewCmdCreate(f cmdutils.Factory) *cobra.Command {
 	cmdutils.EnableRepoOverride(cmd, f)
 	cmd.Flags().StringVarP(&opts.group, "group", "g", "", "Create a group access token. Ignored if a user or repository argument is set.")
 	cmd.Flags().StringVarP(&opts.user, "user", "U", "", "Create a personal access token. For the current user, use @me.")
-	cmd.Flags().StringVarP(&opts.description, "description", "", "description", "Sets the token's description.")
+	cmd.Flags().StringVarP(&opts.description, "description", "", "", "Sets the token's description.")
 	cmd.Flags().VarP(&opts.duration, "duration", "D", "Sets the token lifetime in days. Accepts: days (30d), weeks (4w), or hours in multiples of 24 (24h, 168h, 720h). Maximum: 365d. The token expires at midnight UTC on the calculated date.")
 	cmd.Flags().VarP(&opts.expireAt, "expires-at", "E", "Sets the token's expiration date and time, in YYYY-MM-DD format. If not specified, --duration is used.")
 	cmd.Flags().StringSliceVarP(&opts.scopes, "scope", "S", []string{"read_repository"}, "Scopes for the token. Multiple scopes can be comma-separated or specified by repeating the flag. For a list, see https://docs.gitlab.com/user/profile/personal_access_tokens/#personal-access-token-scopes.")
@@ -145,7 +145,7 @@ func (o *options) validate(cmd *cobra.Command) error {
 
 func (o *options) run() error {
 	// NOTE: this command can not only be used for projects,
-	// so we have to manually check for the base repo, it it doesn't exist,
+	// so we have to manually check for the base repo, if it doesn't exist,
 	// we bootstrap the client with the default hostname.
 	var repoHost string
 	if baseRepo, err := o.baseRepo(); err == nil {
